@@ -52,6 +52,17 @@ my $configure_gnusocial=sub {
    my $verified_email=$_[5]||'';
    my $permanent_ip=$_[6]||'';
    my $site_name=$_[7]||'';
+   my $site_profile=$_[8]||'';
+   my $site_build=$_[9]||'';
+   if ($site_profile=~/Commmunity/) {
+      $site_profile='community';
+   } elsif ($site_profile=~/Public/) {
+      $site_profile='public';
+   } elsif ($site_profile=~/Single/) {
+      $site_profile='singleuser';
+   } elsif ($site_profile=~/Private/) {
+      $site_profile='private';
+   }
    $permanent_ip='' if $permanent_ip=~/Stay|Reason/;
    if ($permanent_ip=~/Elastic/ && exists $main::aws->{permanent_ip}) {
       $permanent_ip=$main::aws->{permanent_ip}; 
@@ -142,7 +153,7 @@ print "\n\n\n\n\n\n\nWE SHOULD HAVE INSTALLED MARIADB=$stdout<==\n\n\n\n\n\n\n";
          "sudo yum -y -v install git-all",'__display__');
    }
    ($stdout,$stderr)=$handle->cmd(
-      "git clone -v https://git.gnu.io/gnu/gnu-social.git",'__display__');
+      "git clone -v -b $site_build https://git.gnu.io/gnu/gnu-social.git",'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "sudo cp -Rv gnu-social /var/www/gnusocial",'__display__');
    ($stdout,$stderr)=$handle->cwd('/var/www/gnusocial');
@@ -735,8 +746,8 @@ END
          'admin_password' => 'admin',
          'admin_password2' => 'admin',
          'admin_email' => $verified_email,
-         'site_profile' => 'public',
-         'submit' => 'Submit',
+         'site_profile' => $site_profile,
+         'submit' => 'Submit'
       ],
    );
    print $response->content;    
@@ -907,6 +918,8 @@ my $standup_gnusocial=sub {
    my $gnusocial="]T[{select_gnusocial_setup}";
    my $permanent_ip="]T[{permanent_ip}";
    my $site_name="]I[{'gnusocial_enter_site_name',1}";
+   my $site_profile="]T[{choose_site_profile}";
+   my $site_build="]T[{choose_build}";
    #if (-1<index $site_name, ']T[') {
    #   $site_name="]I[{'gnusocial_enter_domain_name',1}"; 
    #}
@@ -959,13 +972,13 @@ my $standup_gnusocial=sub {
       if ($#{$main::aws->{'GNU.io/Social'}}==0) {
          launch_server('GNU.io/Social',$cnt,$gnusocial,'',$c,
          $configure_gnusocial,'',$region,$verified_email,
-         $permanent_ip,$site_name);
+         $permanent_ip,$site_name,$site_profile,$site_build);
       } else {
          my $num=$#{$main::aws->{'GNU.io/Social'}}-1;
          foreach my $num (0..$num) {
             launch_server('GNU.io/Social',$cnt++,$gnusocial,'',$c,
             $configure_gnusocial,'',$region,$verified_email,
-            $permanent_ip,$site_name);
+            $permanent_ip,$site_name,$site_profile,$site_build);
          }
       }
    }
@@ -1398,6 +1411,101 @@ END
 
 };
 
+our $gnusocial_choose_build=sub {
+
+   use JSON::XS;
+   my $c='wget -qO- https://api.github.com/users/foocorp/repos';
+   my $local=connect_shell();
+   my ($stdout,$stderr)=('','');
+   ($stdout,$stderr)=$local->cmd($c);
+   my @repos=();
+   @repos=decode_json($stdout);
+   my $default_branch=$repos[0]->[1]->{'default_branch'};
+   my $updated=$repos[0]->[1]->{'updated_at'};
+   my @branches=();
+   $c='wget -qO- https://api.github.com/repos/foocorp/gnu-social/branches';
+   ($stdout,$stderr)=$local->cmd($c);
+   @branches=decode_json($stdout);
+   my @builds=();
+   $updated=~s/^(.*)T.*$/$1/;
+   my $scrollnum=0;my $count=0;
+   foreach my $branch (@{$branches[0]}) {
+      $count++;
+      print "BRANCH NAME=",$branch->{name},"\n";
+      push @builds,$branch->{name};
+      if ($default_branch eq $branch->{name}) {
+         $scrollnum=$count;
+      }
+   }
+   my $gnusocial_build_banner=<<'END';
+     ___ _                       ___      _ _    _  __   __          _
+    / __| |_  ___  ___ ___ ___  | _ )_  _(_) |__| | \ \ / /__ _ _ __(_)___ _ _
+   | (__| ' \/ _ \/ _ (_-</ -_) | _ \ || | | / _` |  \ V / -_) '_(_-< / _ \ ' \
+    \___|_||_\___/\___/__/\___| |___/\_,_|_|_\__,_|   \_/\___|_| /__/_\___/_||_|
+
+END
+   $gnusocial_build_banner.=<<END;
+   There are different versions of GNU Social available. If you are *NOT* a
+   developer, it is highly recommended that you choose the \"$default_branch\"
+   branch. It is set as the default (with the arrow >).
+
+   For more information:  https://github.com/foocorp/gnu-social/branches
+
+   The GNU Social project was last updated:  $updated
+
+END
+   my %choose_build=(
+
+      Name => 'choose_build',
+      Item_1 => {
+
+         Text => ']C[',
+         Convey => \@builds,
+         Result => $gnusocial_setup_summary
+
+      },
+      Scroll => $scrollnum,
+      Banner => $gnusocial_build_banner,
+   );
+   return \%choose_build
+
+};
+
+our $gnusocial_choose_site_profile=sub {
+
+   my $gnusocial_profile_banner=<<'END';
+
+     ___ _                       ___ _ _         ___          __ _ _
+    / __| |_  ___  ___ ___ ___  / __(_) |_ ___  | _ \_ _ ___ / _(_) |___
+   | (__| ' \/ _ \/ _ (_-</ -_) \__ \ |  _/ -_) |  _/ '_/ _ \  _| | / -_)
+    \___|_||_\___/\___/__/\___| |___/_|\__\___| |_| |_| \___/_| |_|_\___|
+
+   Please choose the kind of GNU Social site you'd like to set up.
+
+END
+   my %choose_site_profile=(
+
+      Name => 'choose_site_profile',
+      Item_1 => {
+
+         Text => ']C[',
+         Convey => [
+                      'Community',
+                      'Public (open registration)',
+                      'Single User',
+                      'Private (no federation)'
+                   ],
+         #Result => $gnusocial_setup_summary
+         Result => $gnusocial_choose_build,
+
+      },
+      Scroll => 2,
+      Banner => $gnusocial_profile_banner,
+   );
+   return \%choose_site_profile
+
+};
+
 our $gnusocial_enter_site_name=sub {
 
    my $gnusocial_site_banner=<<'END';
@@ -1432,7 +1540,7 @@ END
       Name => 'gnusocial_enter_site_name',
       Input => 1,
       #Result => $gnusocial_validate_domain,
-      Result => $gnusocial_setup_summary,
+      Result => $gnusocial_choose_site_profile,
       Banner => $gnusocial_site_banner,
 
    };
@@ -1468,8 +1576,8 @@ print "DOMAIN=$domain\n";<STDIN>;
       STDOUT->autoflush(0);
       return '<';
    }
-   my $c="aws ses verify-email-identity --email-address $domain";
-   my ($hash,$output,$error)=&Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+   $c="aws ses verify-email-identity --email-address $domain";
+   ($hash,$output,$error)=&Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
    my $inform_banner=<<'END';
 
     ___                     _            _   _
